mean_cost — skchange

Skip to main content
`Ctrl`+`K`

# mean_cost

mean_cost(precomputed_params: tuple[ndarray, ndarray, ndarray], starts: ndarray, ends: ndarray) → ndarray

  Calculate the Gaussian mean likelihood cost for each segment.

  Parameters:
    precomputed_paramstuple[np.ndarray, np.ndarray, np.ndarray]

      Precomputed parameters from init_mean_cost.

    startsnp.ndarray

      Start indices of the segments.

    endsnp.ndarray

      End indices of the segments.

  Returns:
    costsnp.ndarray

      Costs for each segment.